==> ejc-filesystem-api-3.0.0-20240930.082447-13-sources.jar: com/ejianc/business/filesystem/file/vo/FileTypeVO.java <==
package com.ejianc.business.filesystem.file.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 文件分类
 * 
 * @author generator
 * 
 */
public class FileTypeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String workTypeName; // 文件类型
    private String description; // 描述
    private String enable; // 是否启用(0:未启用-1:启用)
    private Long lastTypeId; // 上级节点id
    private String lastTypeName; // 上级节点名称
    private Integer sortIndex; // 排序索引
    private String innerCode; // 内码
    private String innerName; // 内码名称
    private List<FileTypeVO> children;//树形结构
    private String docPrefix; // 档号前缀
    private String docMemo; // 档号规范说明
    private String isDoc; // 是否档案


    public String getDocPrefix() {
        return docPrefix;
    }

    public void setDocPrefix(String docPrefix) {
        this.docPrefix = docPrefix;
    }

    public String getDocMemo() {
        return docMemo;
    }

    public void setDocMemo(String docMemo) {
        this.docMemo = docMemo;
    }

    public String getIsDoc() {
        return isDoc;
    }

    public void setIsDoc(String isDoc) {
        this.isDoc = isDoc;
    }

    public List<FileTypeVO> getChildren() {
        return children;
    }

    public void setChildren(List<FileTypeVO> children) {
        this.children = children;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public String getEnable() {
        return enable;
    }

    public void setEnable(String enable) {
        this.enable = enable;
    }
    @ReferSerialTransfer(referCode="filesystem-workType")
    public Long getLastTypeId() {
        return lastTypeId;
    }
    @ReferDeserialTransfer
    public void setLastTypeId(Long lastTypeId) {
        this.lastTypeId = lastTypeId;
    }
    public String getLastTypeName() {
        return lastTypeName;
    }

    public void setLastTypeName(String lastTypeName) {
        this.lastTypeName = lastTypeName;
    }
    public Integer getSortIndex() {
        return sortIndex;
    }

    public void setSortIndex(Integer sortIndex) {
        this.sortIndex = sortIndex;
    }
    public String getInnerCode() {
        return innerCode;
    }

    public void setInnerCode(String innerCode) {
        this.innerCode = innerCode;
    }
    public String getInnerName() {
        return innerName;
    }

    public void setInnerName(String innerName) {
        this.innerName = innerName;
    }
    
}

==> ejc-filesystem-api-3.0.0-20250821.083512-47-sources.jar: com/ejianc/business/filesystem/file/vo/FileTypeVO.java <==
package com.ejianc.business.filesystem.file.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 文件分类
 * 
 * @author generator
 * 
 */
public class FileTypeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String workTypeName; // 文件类型
    private String description; // 描述
    private String enable; // 是否启用(0:未启用-1:启用)
    private Long lastTypeId; // 上级节点id
    private String lastTypeName; // 上级节点名称
    private Integer sortIndex; // 排序索引
    private String innerCode; // 内码
    private String innerName; // 内码名称
    private List<FileTypeVO> children;//树形结构
    private String docPrefix; // 档号前缀
    private String docMemo; // 档号规范说明
    private String isDoc; // 是否档案
    private List<FileTypeDetailVO> fileTypeDetailList = new ArrayList<>(); // 工程案卷规范


    public List<FileTypeDetailVO> getFileTypeDetailList() {
        return fileTypeDetailList;
    }

    public void setFileTypeDetailList(List<FileTypeDetailVO> fileTypeDetailList) {
        this.fileTypeDetailList = fileTypeDetailList;
    }

    public String getDocPrefix() {
        return docPrefix;
    }

    public void setDocPrefix(String docPrefix) {
        this.docPrefix = docPrefix;
    }

    public String getDocMemo() {
        return docMemo;
    }

    public void setDocMemo(String docMemo) {
        this.docMemo = docMemo;
    }

    public String getIsDoc() {
        return isDoc;
    }

    public void setIsDoc(String isDoc) {
        this.isDoc = isDoc;
    }

    public List<FileTypeVO> getChildren() {
        return children;
    }

    public void setChildren(List<FileTypeVO> children) {
        this.children = children;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public String getEnable() {
        return enable;
    }

    public void setEnable(String enable) {
        this.enable = enable;
    }
    @ReferSerialTransfer(referCode="filesystem-workType")
    public Long getLastTypeId() {
        return lastTypeId;
    }
    @ReferDeserialTransfer
    public void setLastTypeId(Long lastTypeId) {
        this.lastTypeId = lastTypeId;
    }
    public String getLastTypeName() {
        return lastTypeName;
    }

    public void setLastTypeName(String lastTypeName) {
        this.lastTypeName = lastTypeName;
    }
    public Integer getSortIndex() {
        return sortIndex;
    }

    public void setSortIndex(Integer sortIndex) {
        this.sortIndex = sortIndex;
    }
    public String getInnerCode() {
        return innerCode;
    }

    public void setInnerCode(String innerCode) {
        this.innerCode = innerCode;
    }
    public String getInnerName() {
        return innerName;
    }

    public void setInnerName(String innerName) {
        this.innerName = innerName;
    }
    
}
